==> gulp-concat-0.0.33.tgz: gulp-concat/README.md <==
# Installation
> `npm install --save @types/gulp-concat`

# Summary
This package contains type definitions for gulp-concat (https://github.com/wearefractal/gulp-concat).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-concat.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-concat/index.d.ts)
````ts
// Type definitions for gulp-concat
// Project: https://github.com/wearefractal/gulp-concat
// Definitions by: Keita Kagurazaka <https://github.com/k-kagurazaka>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

/// <reference types="node" />



interface IOptions {
    newLine: string;
}

interface IFsStats {
    dev?: number | undefined;
    ino?: number | undefined;
    mode?: number | undefined;
    nlink?: number | undefined;
    uid?: number | undefined;
    gid?: number | undefined;
    rdev?: number | undefined;
    size?: number | undefined;
    blksize?: number | undefined;
    blocks?: number | undefined;
    atime?: Date | undefined;
    mtime?: Date | undefined;
    ctime?: Date | undefined;
}

interface IVinylOptions {
    cwd?: string | undefined;
    base?: string | undefined;
    path?: string | undefined;
    stat?: IFsStats | undefined;
    contents?: NodeJS.ReadableStream | Buffer | undefined;
}

interface IConcat {
    (filename: string, options?: IOptions): NodeJS.ReadWriteStream;
    (options: IVinylOptions): NodeJS.ReadWriteStream;
}

declare var _tmp: IConcat;
export = _tmp;

````

### Additional Details
 * Last updated: Tue, 06 Jul 2021 20:33:09 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)
 * Global values: none

# Credits
These definitions were written by [Keita Kagurazaka](https://github.com/k-kagurazaka).

==> gulp-concat-0.0.35.tgz: gulp-concat/README.md <==
# Installation
> `npm install --save @types/gulp-concat`

# Summary
This package contains type definitions for gulp-concat (https://github.com/wearefractal/gulp-concat).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-concat.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-concat/index.d.ts)
````ts
// Type definitions for gulp-concat
// Project: https://github.com/wearefractal/gulp-concat
// Definitions by: Keita Kagurazaka <https://github.com/k-kagurazaka>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

/// <reference types="node" />

interface IOptions {
    newLine: string;
}

interface IFsStats {
    dev?: number | undefined;
    ino?: number | undefined;
    mode?: number | undefined;
    nlink?: number | undefined;
    uid?: number | undefined;
    gid?: number | undefined;
    rdev?: number | undefined;
    size?: number | undefined;
    blksize?: number | undefined;
    blocks?: number | undefined;
    atime?: Date | undefined;
    mtime?: Date | undefined;
    ctime?: Date | undefined;
}

interface IVinylOptions {
    cwd?: string | undefined;
    base?: string | undefined;
    path?: string | undefined;
    stat?: IFsStats | undefined;
    contents?: NodeJS.ReadableStream | Buffer | undefined;
}

interface IConcat {
    (filename: string, options?: IOptions): NodeJS.ReadWriteStream;
    (options: IVinylOptions): NodeJS.ReadWriteStream;
}

declare var _tmp: IConcat;
export = _tmp;

````

### Additional Details
 * Last updated: Wed, 20 Sep 2023 17:08:03 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)
 * Global values: none

# Credits
These definitions were written by [Keita Kagurazaka](https://github.com/k-kagurazaka).
